@@ -16,51 +16,34 @@
 
 import logging as _logging
 
-from .version import (
-    __version__,
-    version,
-    version_info
-)
-
-from .settings import settings, USER_SETTINGS, BASE_SETTINGS
+from .settings import BASE_SETTINGS, USER_SETTINGS, settings
+from .version import __version__, version, version_info
 
 # SET UP NULL LOG HANDLER
 _logger = _logging.getLogger(__name__)
 _logger.setLevel(_logging.DEBUG)
 _logger.addHandler(_logging.NullHandler())
 
-from .mapping import (
-    map,
-    starmap,
-    build_map,
-    MapBuilder,
-)
-from .mapped import mapped, MappedFunction
-from .maps import (
-    Map,
-    MapStdOut,
-    MapStdErr,
-    MapOutputFiles,
-)
-from .holds import ComponentHold
+from . import _startup, exceptions
+from .checkpointing import checkpoint
 from .errors import ComponentError
-from .state import ComponentStatus
-from .options import MapOptions, register_delivery_method
+from .holds import ComponentHold
 from .management import (
-    status,
-    status_json,
-    status_csv,
+    Transplant,
+    clean,
     load,
     load_maps,
     remove,
-    clean,
-    Transplant,
-    transplants,
+    status,
+    status_csv,
+    status_json,
     transplant_info,
+    transplants,
 )
+from .mapped import MappedFunction, mapped
+from .mapping import MapBuilder, build_map, map, starmap
+from .maps import Map, MapOutputFiles, MapStdErr, MapStdOut
+from .options import MapOptions, register_delivery_method
+from .state import ComponentStatus
 from .tags import get_tags
-from .checkpointing import checkpoint
 from .transfer import TransferPath, transfer_output_files
-from . import exceptions
-
-from . import _startup
