@@ -20,10 +20,10 @@ from htmap import settings
 
 def get_schedd() -> htcondor.Schedd:
     """Get the :class:`htcondor.Schedd` that represents the HTCondor scheduler."""
-    s = settings['HTCONDOR.SCHEDULER']
+    s = settings["HTCONDOR.SCHEDULER"]
     if s is None:
         return htcondor.Schedd()
 
-    coll = htcondor.Collector(settings['HTCONDOR.COLLECTOR'])
+    coll = htcondor.Collector(settings["HTCONDOR.COLLECTOR"])
     schedd_ad = coll.locate(htcondor.DaemonTypes.Schedd, s)
     return htcondor.Schedd(schedd_ad)
