@@ -13,21 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Tuple, Iterable, Dict, Union, NamedTuple, Callable, List, Optional
-import logging
-
-from pathlib import Path
-import datetime
 import collections
-import json
 import csv
+import datetime
 import io
-import textwrap
+import json
+import logging
 import shutil
+import textwrap
 import uuid
 from concurrent.futures.thread import ThreadPoolExecutor
+from pathlib import Path
+from typing import Callable, Dict, Iterable, List, NamedTuple, Optional, Tuple, Union
 
-from . import maps, tags, mapping, utils, state, names, settings, exceptions
+from . import exceptions, mapping, maps, names, settings, state, tags, utils
 
 logger = logging.getLogger(__name__)
 
@@ -85,7 +84,7 @@ def remove(tag: str, not_exist_ok: bool = True) -> None:
     except (exceptions.TagNotFound, FileNotFoundError) as e:
         if not not_exist_ok:
             if not isinstance(e, exceptions.TagNotFound):
-                raise exceptions.TagNotFound(f'Map {tag} not found') from e
+                raise exceptions.TagNotFound(f"Map {tag} not found") from e
             raise e
 
 
@@ -109,7 +108,7 @@ def clean(*, all: bool = False) -> List[str]:
     cleaned_tags
         A list of the tags of the maps that were removed.
     """
-    logger.debug('Cleaning maps...')
+    logger.debug("Cleaning maps...")
     cleaned_tags = []
     for map in load_maps():
         if map.is_transient or all:
@@ -123,20 +122,18 @@ def clean(*, all: bool = False) -> List[str]:
         map_dir = mapping.map_dir_path(uuid.UUID(uid.stem))
         try:
             shutil.rmtree(map_dir)
-            logger.debug(f'Removed orphaned map directory {uid.stem}')
+            logger.debug(f"Removed orphaned map directory {uid.stem}")
         except (OSError, FileNotFoundError):
-            logger.exception(f'Failed to remove orphaned map directory {uid.stem}')
+            logger.exception(f"Failed to remove orphaned map directory {uid.stem}")
 
-    logger.debug(f'Cleaned maps {cleaned_tags}')
+    logger.debug(f"Cleaned maps {cleaned_tags}")
     return cleaned_tags
 
 
 def _extract_status_data(
-    map: maps.Map,
-    include_state: bool = True,
-    include_meta: bool = True,
+    map: maps.Map, include_state: bool = True, include_meta: bool = True,
 ) -> dict:
-    sd = {'Tag': f'{"* " if map.is_transient else ""}{map.tag}'}
+    sd = {"Tag": f'{"* " if map.is_transient else ""}{map.tag}'}
 
     if include_state:
         sc = collections.Counter(map.component_statuses)
@@ -144,10 +141,10 @@ def _extract_status_data(
         sd.update({str(k): str(sc[k]) for k in state.ComponentStatus.display_statuses()})
 
     if include_meta:
-        sd['Local Data'] = utils.num_bytes_to_str(map.local_data)
-        sd['Max Memory'] = utils.num_bytes_to_str(max(map.memory_usage) * 1024 * 1024)
-        sd['Max Runtime'] = str(max(map.runtime))
-        sd['Total Runtime'] = str(sum(map.runtime, datetime.timedelta()))
+        sd["Local Data"] = utils.num_bytes_to_str(map.local_data)
+        sd["Max Memory"] = utils.num_bytes_to_str(max(map.memory_usage) * 1024 * 1024)
+        sd["Max Runtime"] = str(max(map.runtime))
+        sd["Total Runtime"] = str(sum(map.runtime, datetime.timedelta()))
 
     return sd
 
@@ -175,11 +172,7 @@ def status(
     table :
         A text table containing information on the given maps.
     """
-    return _status(
-        maps = maps,
-        include_state = include_state,
-        include_meta = include_meta,
-    )
+    return _status(maps=maps, include_state=include_state, include_meta=include_meta,)
 
 
 def _status(
@@ -190,26 +183,26 @@ def _status(
     row_fmt: Optional[Callable[[str], str]] = None,
 ) -> str:
     if maps is None:
-        maps = sorted(load_maps(), key = lambda m: (m.is_transient, m.tag))
+        maps = sorted(load_maps(), key=lambda m: (m.is_transient, m.tag))
 
-    headers = ['Tag']
+    headers = ["Tag"]
     if include_state:
         read_events(maps)
         headers += [str(d) for d in state.ComponentStatus.display_statuses()]
     if include_meta:
-        headers += ['Local Data', 'Max Memory', 'Max Runtime', 'Total Runtime']
+        headers += ["Local Data", "Max Memory", "Max Runtime", "Total Runtime"]
 
     rows = [
-        _extract_status_data(map, include_state = include_state, include_meta = include_meta)
+        _extract_status_data(map, include_state=include_state, include_meta=include_meta)
         for map in maps
     ]
 
     return utils.table(
-        headers = headers,
-        rows = rows,
-        header_fmt = header_fmt,
-        row_fmt = row_fmt,
-        alignment = {'Tag': 'ljust'},
+        headers=headers,
+        rows=rows,
+        header_fmt=header_fmt,
+        row_fmt=row_fmt,
+        alignment={"Tag": "ljust"},
     )
 
 
@@ -245,7 +238,7 @@ def status_json(
     if maps is None:
         maps = load_maps()
 
-    maps = sorted(maps, key = lambda m: m.tag)
+    maps = sorted(maps, key=lambda m: m.tag)
 
     if include_state:
         read_events(maps)
@@ -253,28 +246,28 @@ def status_json(
     j = {}
     for map in maps:
         sc = collections.Counter(map.component_statuses)
-        d: Dict[str, Union[dict, str, int, float]] = {'tag': map.tag}
+        d: Dict[str, Union[dict, str, int, float]] = {"tag": map.tag}
         if include_state:
             status_to_count = {}
             for status in state.ComponentStatus.display_statuses():
                 status_to_count[status.value.lower()] = sc[status]
-            d['component_status_counts'] = status_to_count
+            d["component_status_counts"] = status_to_count
         if include_meta:
-            d['local_disk_usage'] = utils.get_dir_size(mapping.map_dir_path(map.tag))
-            d['max_memory_usage'] = max(map.memory_usage) * 1024 * 1024
-            d['max_runtime'] = max(map.runtime).total_seconds()
-            d['total_runtime'] = sum(map.runtime, datetime.timedelta()).total_seconds()
+            d["local_disk_usage"] = utils.get_dir_size(mapping.map_dir_path(map.tag))
+            d["max_memory_usage"] = max(map.memory_usage) * 1024 * 1024
+            d["max_runtime"] = max(map.runtime).total_seconds()
+            d["total_runtime"] = sum(map.runtime, datetime.timedelta()).total_seconds()
 
         j[map.tag] = d
 
     if compact:
-        separators = (',', ':')
+        separators = (",", ":")
         indent = None
     else:
-        separators = (', ', ': ')
+        separators = (", ", ": ")
         indent = 4
 
-    return json.dumps(j, separators = separators, indent = indent)
+    return json.dumps(j, separators=separators, indent=indent)
 
 
 def status_csv(
@@ -306,7 +299,7 @@ def status_csv(
     if maps is None:
         maps = load_maps()
 
-    maps = sorted(maps, key = lambda m: m.tag)
+    maps = sorted(maps, key=lambda m: m.tag)
 
     if include_state:
         read_events(maps)
@@ -314,20 +307,20 @@ def status_csv(
     rows = []
     for map in maps:
         sc = collections.Counter(map.component_statuses)
-        row: Dict[str, Union[str, int, float]] = {'tag': map.tag}
+        row: Dict[str, Union[str, int, float]] = {"tag": map.tag}
         if include_state:
             for status in state.ComponentStatus.display_statuses():
                 row[status.value.lower()] = sc[status]
         if include_meta:
-            row['local_disk_usage'] = utils.get_dir_size(mapping.map_dir_path(map.tag))
-            row['max_memory_usage'] = max(map.memory_usage) * 1024 * 1024
-            row['max_runtime'] = max(map.runtime).total_seconds()
-            row['total_runtime'] = sum(map.runtime, datetime.timedelta()).total_seconds()
+            row["local_disk_usage"] = utils.get_dir_size(mapping.map_dir_path(map.tag))
+            row["max_memory_usage"] = max(map.memory_usage) * 1024 * 1024
+            row["max_runtime"] = max(map.runtime).total_seconds()
+            row["total_runtime"] = sum(map.runtime, datetime.timedelta()).total_seconds()
 
         rows.append(row)
 
     if len(maps) == 0:
-        return ''
+        return ""
 
     output = io.StringIO()
     writer = csv.DictWriter(output, list(rows[0]))
@@ -363,44 +356,42 @@ class Transplant(NamedTuple):
         """
 
         return cls(
-            hash = path.stem,
-            path = path,
-            created = datetime.datetime.fromtimestamp(path.stat().st_ctime),
-            size = path.stat().st_size,
-            packages = tuple(path.with_suffix('.pip').read_text().strip().split('\n')),
+            hash=path.stem,
+            path=path,
+            created=datetime.datetime.fromtimestamp(path.stat().st_ctime),
+            size=path.stat().st_size,
+            packages=tuple(path.with_suffix(".pip").read_text().strip().split("\n")),
         )
 
     def remove(self):
-        self.path.with_suffix('.pip').unlink()
+        self.path.with_suffix(".pip").unlink()
         self.path.unlink()
-        logger.info(f'Removed transplant install {self.hash}, which was created at {self.created}')
+        logger.info(f"Removed transplant install {self.hash}, which was created at {self.created}")
 
 
 def transplants() -> Tuple[Transplant, ...]:
-    return tuple(sorted(
-        (
-            Transplant.load(p)
-            for p in Path(settings['TRANSPLANT.DIR']).iterdir()
-            if p.suffix != '.pip'
-        ),
-        key = lambda t: t.created,
-    ))
+    return tuple(
+        sorted(
+            (
+                Transplant.load(p)
+                for p in Path(settings["TRANSPLANT.DIR"]).iterdir()
+                if p.suffix != ".pip"
+            ),
+            key=lambda t: t.created,
+        )
+    )
 
 
 def transplant_info() -> str:
     entries = []
     for q, t in enumerate(transplants()):
-        packages = '\n'.join(
-            textwrap.wrap(
-                ', '.join(t.packages),
-                subsequent_indent = ' ' * 4,
-                break_long_words = False,
-            )
+        packages = "\n".join(
+            textwrap.wrap(", ".join(t.packages), subsequent_indent=" " * 4, break_long_words=False,)
         )
-        entry = f'# {q}\nHash: {t.hash}\nCreated at: {t.created}\nPackages: {packages}'
+        entry = f"# {q}\nHash: {t.hash}\nCreated at: {t.created}\nPackages: {packages}"
         entries.append(entry)
 
-    return utils.rstr('\n\n'.join(entries))
+    return utils.rstr("\n\n".join(entries))
 
 
 def read_events(maps: Iterable[maps.Map]) -> None:
