@@ -13,20 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Iterable, Dict, Union, Optional, Callable, Any
 import logging
+from typing import Any, Callable, Dict, Iterable, Optional, Union
 
-from . import mapping, options, maps
+from . import mapping, maps, options
 
 logger = logging.getLogger(__name__)
 
 
 class MappedFunction:
-    def __init__(
-        self,
-        func: Callable,
-        map_options: Optional[options.MapOptions] = None
-    ):
+    def __init__(self, func: Callable, map_options: Optional[options.MapOptions] = None):
         """
         Parameters
         ----------
@@ -42,10 +38,10 @@ class MappedFunction:
             map_options = options.MapOptions()
         self.map_options = map_options
 
-        logger.debug(f'Created mapped function for {self.func} with options {self.map_options}')
+        logger.debug(f"Created mapped function for {self.func} with options {self.map_options}")
 
     def __repr__(self):
-        return f'{self.__class__.__name__}(func = {self.func}, map_options = {self.map_options})'
+        return f"{self.__class__.__name__}(func = {self.func}, map_options = {self.map_options})"
 
     def __call__(self, *args, **kwargs):
         """Call the function as normal, locally."""
@@ -62,10 +58,10 @@ class MappedFunction:
             map_options = options.MapOptions()
 
         return mapping.map(
-            func = self.func,
-            args = args,
-            tag = tag,
-            map_options = options.MapOptions.merge(map_options, self.map_options),
+            func=self.func,
+            args=args,
+            tag=tag,
+            map_options=options.MapOptions.merge(map_options, self.map_options),
         )
 
     def starmap(
@@ -80,30 +76,28 @@ class MappedFunction:
             map_options = options.MapOptions()
 
         return mapping.starmap(
-            func = self.func,
-            args = args,
-            kwargs = kwargs,
-            tag = tag,
-            map_options = options.MapOptions.merge(map_options, self.map_options),
+            func=self.func,
+            args=args,
+            kwargs=kwargs,
+            tag=tag,
+            map_options=options.MapOptions.merge(map_options, self.map_options),
         )
 
     def build_map(
-        self,
-        tag: Optional[str] = None,
-        map_options: Optional[options.MapOptions] = None,
+        self, tag: Optional[str] = None, map_options: Optional[options.MapOptions] = None,
     ) -> mapping.MapBuilder:
         """As :func:`htmap.build_map`, but the ``func`` argument is the mapped function."""
         if map_options is None:
             map_options = options.MapOptions()
 
         return mapping.build_map(
-            func = self.func,
-            tag = tag,
-            map_options = options.MapOptions.merge(map_options, self.map_options),
+            func=self.func,
+            tag=tag,
+            map_options=options.MapOptions.merge(map_options, self.map_options),
         )
 
 
-def mapped(map_options: Optional[options.MapOptions] = None) -> Union[Callable, MappedFunction]:
+def mapped(map_options: Optional[options.MapOptions] = None,) -> Union[Callable, MappedFunction]:
     """
     A decorator that wraps a function in an :class:`MappedFunction`,
     which provides an interface for mapping functions calls out to an HTCondor cluster.
@@ -120,6 +114,7 @@ def mapped(map_options: Optional[options.MapOptions] = None) -> Union[Callable,
         A :class:`MappedFunction` that wraps the function (or a wrapper function that does the wrapping).
     """
     if map_options is None:  # call with parens but no args
+
         def wrapper(func: Callable) -> MappedFunction:
             return MappedFunction(func)
 
@@ -129,9 +124,12 @@ def mapped(map_options: Optional[options.MapOptions] = None) -> Union[Callable,
         return MappedFunction(map_options)
 
     elif isinstance(map_options, options.MapOptions):  # call with map options
+
         def wrapper(func: Callable) -> MappedFunction:
-            return MappedFunction(func, map_options = map_options)
+            return MappedFunction(func, map_options=map_options)
 
         return wrapper
 
-    raise TypeError('incorrect use of @mapped decorator: argument should be a callable or a MapOptions, or no argument')
+    raise TypeError(
+        "incorrect use of @mapped decorator: argument should be a callable or a MapOptions, or no argument"
+    )
