@@ -13,16 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Tuple, Optional
+from typing import Optional, Tuple
+
+try:
+    from importlib import metadata
+except ImportError:
+    # Running on pre-3.8 Python; use importlib-metadata package
+    import importlib_metadata as metadata
 
 from . import utils
 
-__version__ = '0.6.0'
+__version__ = metadata.version("htmap")
 
 
 def version() -> str:
     """Return a string containing human-readable version information."""
-    return f'HTMap version {__version__}'
+    return f"HTMap version {__version__}"
 
 
 def version_info() -> Tuple[int, int, int, Optional[str], Optional[int]]:
